@@ -89,15 +89,25 @@ namespace glz
 
    // Read and write numbers as strings
    template <auto MemPtr>
-   constexpr auto quoted_num = opts_wrapper<MemPtr, &opts::quoted_num>();
+   constexpr auto quoted_num = opts_wrapper<MemPtr, quoted_num_opt_tag{}>();
 
-   // Treat types like std::string as numbers: read and write them quoted
+   // Treat types like std::string as numbers: read and write them without quotes
    template <auto MemPtr>
-   constexpr auto number = opts_wrapper<MemPtr, &opts::number>();
+   constexpr auto string_as_number = opts_wrapper<MemPtr, string_as_number_opt_tag{}>();
+
+   // Deprecated: use string_as_number instead
+   template <auto MemPtr>
+   [[deprecated("Use glz::string_as_number instead of glz::number")]]
+   constexpr auto number = opts_wrapper<MemPtr, string_as_number_opt_tag{}>();
 
    // Write out string like types without quotes
    template <auto MemPtr>
-   constexpr auto raw = opts_wrapper<MemPtr, &opts::raw>();
+   constexpr auto unquoted = opts_wrapper<MemPtr, unquoted_opt_tag{}>();
+
+   // Deprecated: use unquoted instead
+   template <auto MemPtr>
+   [[deprecated("Use glz::unquoted instead of glz::raw")]]
+   constexpr auto raw = opts_wrapper<MemPtr, unquoted_opt_tag{}>();
 
    // Reads into only existing fields and elements and then exits without parsing the rest of the input
    template <auto MemPtr>
@@ -116,4 +126,31 @@ namespace glz
    // Treat char arrays as byte sequences to be fully escaped
    template <auto MemPtr>
    constexpr auto escape_bytes = escape_bytes_impl<MemPtr>();
+
+   // Limit string length or array size when reading
+   // For strings: limits max_string_length
+   // For arrays/vectors: limits max_array_size
+   template <class T, size_t MaxLen>
+   struct max_length_t
+   {
+      static constexpr bool glaze_wrapper = true;
+      static constexpr auto glaze_reflect = false;
+      static constexpr size_t max_len = MaxLen;
+      using value_type = T;
+      T& val;
+   };
+
+   template <auto MemPtr, size_t MaxLen>
+   inline constexpr decltype(auto) max_length_impl() noexcept
+   {
+      return [](auto&& val) {
+         using V = std::remove_reference_t<decltype(val.*MemPtr)>;
+         return max_length_t<V, MaxLen>{val.*MemPtr};
+      };
+   }
+
+   // Limit string length or array size when reading from binary formats
+   // Usage: glz::max_length<&T::field, 100>
+   template <auto MemPtr, size_t MaxLen>
+   constexpr auto max_length = max_length_impl<MemPtr, MaxLen>();
 }
